RBENV_ROOT=`rbenv root`

PREFIX_MAN="$(rbenv prefix)/share/man"
ROOT_MAN="${RBENV_ROOT}/share/man"
EXEC_HOOK_DIR="${RBENV_ROOT}/plugins/manpages/etc/rbenv.d/exec"
INSTALL_HOOK_DIR="${RBENV_ROOT}/plugins/manpages/etc/rbenv.d/install"
